#
# VDR shutdown hook for ACPI - Tobias Grimm <vdr@e-tobi.net>
# --------------------------
#
# This shutdown hook sets the wakeup time for the next timer using
# ACPI. 
#

# read arguments for nvram-wakeup from conf-file
. /etc/vdr/vdr-addon-acpiwakeup.conf

# Defaults:
[ -z "$ACPI_ENABLED" ]        && export ACPI_ENABLED="yes"
[ -z "$ACPI_ALARM" ]          && export ACPI_ALARM="/proc/acpi/alarm"
[ -z "$ACPI_REGULAR_DAYS" ]   && export ACPI_REGULAR_DAYS="0"
[ -z "$ACPI_REGULAR_TIME" ]   && export ACPI_REGULAR_TIME="00:00"
[ -z "$ACPI_START_AHEAD" ]    && export ACPI_START_AHEAD="5"

LOG="logger -t vdr-addon-acpiwakeup "
TIMER=$1

if [ $ACPI_ENABLED = "yes" ]; then
    # check if we should wake up before the next timer:
    if [ $ACPI_REGULAR_DAYS -gt 0 ]; then
	REGULAR_TIMER=$((`date -d "$ACPI_REGULAR_TIME" +%s` + 24 * 60 * 60))
	if [ $TIMER -gt 0 ] && [ $REGULAR_TIMER -lt $TIMER ]; then
	    TIMER=$REGULAR_TIMER
	fi
    fi
    if [ $TIMER -gt 0 ]; then
	TIMER=$(($TIMER - 60 * $ACPI_START_AHEAD))
    fi

    if [ $TIMER -gt 0 ] && [ $TIMER -lt $((`date +%s` + 5 * 60)) ]; then
	$LOG "Can not set wakeup time less than 5 minutes ahead."
	ABORT_MESSAGE="Wakeup in less than 5 minutes, aborting!"
	EXITCODE=1
    else
        # set the wakeup time
	if [ -e $ACPI_ALARM ]; then
	    if [ $TIMER -eq 0 ]; then
		# no wakeup - I don't really now right now, how to disable
		# the wakeup !!!!
		TIME_TO_SET="+0"
	    else
		# convert time_t to YYYY-MM-DD HH:MM:SS
		TIME_TO_SET=$(perl -e "(\$s,\$mi,\$h,\$d,\$mo,\$y,\$t,\$t,\$t)=\
		    localtime($TIMER); printf(\"%04d-%02d-%02d %02d:%02d:%02d\",\
		    \$y+1900,\$mo+1,\$d,\$h,\$mi,\$s);")
	    fi
	    # now set the wakeup time:
	    $LOG "Current ACPI alarm time: `cat $ACPI_ALARM`"
	    $LOG "Setting ACPI alarm time to: $TIME_TO_SET"
	    echo $TIME_TO_SET >$ACPI_ALARM
	    $LOG "New ACPI alarm time: `cat $ACPI_ALARM`"
	else
	    $LOG "$ACPI_ALARM not found. ACPI needed!!!"
	    ABORT_MESSAGE="ACPI not installed, shutdown aborted!"
	    EXITCODE=1    
	fi
    fi
else
    $LOG "ACPIWakeup functionality is disabled"
fi
